@@ -3,25 +3,13 @@ package OpenERP::OOM;
 use warnings;
 use strict;
 
-
-our $VERSION = '0.46';
-
-
-1; # End of OpenERP::OOM
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
-OpenERP::OOM
+OpenERP::OOM - OpenERP Object to Object Mapper
 
-=head1 VERSION
+=cut
 
-version 0.46
+our $VERSION = '0.47';
 
 =head1 SYNOPSIS
 
@@ -37,23 +25,11 @@ Additionally, links can be defined to join OpenERP objects with DBIx::Class
 schemas, so that an OpenERP object can be augmented with additional data
 structures, methods, and application logic that is held outside of OpenERP.
 
-=head1 NAME
-
-OpenERP::OOM - OpenERP Object to Object Mapper
-
 =head1 TUTORIAL
 
 L<OpenERP::OOM::Tutorial> gives a walkthrough of how to use OpenERP::OOM.
 
-=head1 AUTHOR
-
-Jon Allen (JJ), <jj@opusvl.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2011-2016 by OpusVL.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+1; # End of OpenERP::OOM
